@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -704,6 +694,35 @@ namespace Model
      */
     inline Host& WithAvailabilityZoneId(const char* value) { SetAvailabilityZoneId(value); return *this;}
 
+
+    /**
+     * <p>Indicates whether the Dedicated Host is in a host resource group. If
+     * <b>memberOfServiceLinkedResourceGroup</b> is <code>true</code>, the host is in a
+     * host resource group; otherwise, it is not.</p>
+     */
+    inline bool GetMemberOfServiceLinkedResourceGroup() const{ return m_memberOfServiceLinkedResourceGroup; }
+
+    /**
+     * <p>Indicates whether the Dedicated Host is in a host resource group. If
+     * <b>memberOfServiceLinkedResourceGroup</b> is <code>true</code>, the host is in a
+     * host resource group; otherwise, it is not.</p>
+     */
+    inline bool MemberOfServiceLinkedResourceGroupHasBeenSet() const { return m_memberOfServiceLinkedResourceGroupHasBeenSet; }
+
+    /**
+     * <p>Indicates whether the Dedicated Host is in a host resource group. If
+     * <b>memberOfServiceLinkedResourceGroup</b> is <code>true</code>, the host is in a
+     * host resource group; otherwise, it is not.</p>
+     */
+    inline void SetMemberOfServiceLinkedResourceGroup(bool value) { m_memberOfServiceLinkedResourceGroupHasBeenSet = true; m_memberOfServiceLinkedResourceGroup = value; }
+
+    /**
+     * <p>Indicates whether the Dedicated Host is in a host resource group. If
+     * <b>memberOfServiceLinkedResourceGroup</b> is <code>true</code>, the host is in a
+     * host resource group; otherwise, it is not.</p>
+     */
+    inline Host& WithMemberOfServiceLinkedResourceGroup(bool value) { SetMemberOfServiceLinkedResourceGroup(value); return *this;}
+
   private:
 
     AutoPlacement m_autoPlacement;
@@ -753,6 +772,9 @@ namespace Model
 
     Aws::String m_availabilityZoneId;
     bool m_availabilityZoneIdHasBeenSet;
+
+    bool m_memberOfServiceLinkedResourceGroup;
+    bool m_memberOfServiceLinkedResourceGroupHasBeenSet;
   };
 
 } // namespace Model
