@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -646,6 +636,43 @@ namespace Model
     inline InstanceNetworkInterfaceSpecification& WithSubnetId(const char* value) { SetSubnetId(value); return *this;}
 
 
+    /**
+     * <p>Indicates whether to assign a carrier IP address to the network
+     * interface.</p> <p>You can only assign a carrier IP address to a network
+     * interface that is in a subnet in a Wavelength Zone. For more information about
+     * carrier IP addresses, see Carrier IP addresses in the AWS Wavelength Developer
+     * Guide.</p>
+     */
+    inline bool GetAssociateCarrierIpAddress() const{ return m_associateCarrierIpAddress; }
+
+    /**
+     * <p>Indicates whether to assign a carrier IP address to the network
+     * interface.</p> <p>You can only assign a carrier IP address to a network
+     * interface that is in a subnet in a Wavelength Zone. For more information about
+     * carrier IP addresses, see Carrier IP addresses in the AWS Wavelength Developer
+     * Guide.</p>
+     */
+    inline bool AssociateCarrierIpAddressHasBeenSet() const { return m_associateCarrierIpAddressHasBeenSet; }
+
+    /**
+     * <p>Indicates whether to assign a carrier IP address to the network
+     * interface.</p> <p>You can only assign a carrier IP address to a network
+     * interface that is in a subnet in a Wavelength Zone. For more information about
+     * carrier IP addresses, see Carrier IP addresses in the AWS Wavelength Developer
+     * Guide.</p>
+     */
+    inline void SetAssociateCarrierIpAddress(bool value) { m_associateCarrierIpAddressHasBeenSet = true; m_associateCarrierIpAddress = value; }
+
+    /**
+     * <p>Indicates whether to assign a carrier IP address to the network
+     * interface.</p> <p>You can only assign a carrier IP address to a network
+     * interface that is in a subnet in a Wavelength Zone. For more information about
+     * carrier IP addresses, see Carrier IP addresses in the AWS Wavelength Developer
+     * Guide.</p>
+     */
+    inline InstanceNetworkInterfaceSpecification& WithAssociateCarrierIpAddress(bool value) { SetAssociateCarrierIpAddress(value); return *this;}
+
+
     /**
      * <p>The type of network interface. To create an Elastic Fabric Adapter (EFA),
      * specify <code>efa</code>. For more information, see <a
@@ -764,6 +791,9 @@ namespace Model
     Aws::String m_subnetId;
     bool m_subnetIdHasBeenSet;
 
+    bool m_associateCarrierIpAddress;
+    bool m_associateCarrierIpAddressHasBeenSet;
+
     Aws::String m_interfaceType;
     bool m_interfaceTypeHasBeenSet;
   };
